﻿PlayerFramework.Plugins.ErrorMessageControlPlugin = PlayerFramework.ControlPlugin.extend(
{
	defaultOptions: function(player)
	{
		return PlayerFramework.mergeOptions(this._super(),
		{
			defaultMessage: "An error occurred while attempting to play the video."
		});
	},

	init: function(player, options)
	{
		///	<summary>
		///		Initializes the ControlPlugin that displays a message when the media element encounters an error.
		///	</summary>
		///	<param name="player" type="Object">
		///		The Player object.
		///	</param>
		///	<param name="options" type="Object">
		///		The options for the ErrorMessageControlPlugin.
		///	</param>
		///	<returns type="ErrorMessageControlPlugin" />

		this._super(player, options);
	},

	// ControlPlugin Event Handlers
	onError: function(e)
	{
		///	<summary>
		///		Called when the media element encounters an error.
		///	</summary>
		
		if (!this.element &&
			this.mediaPlugin() &&
			this.player.error() &&
			(this.player.error().code === PlayerFramework.VideoMediaPlugin.MediaError.MEDIA_ERR_NETWORK ||
			this.player.error().code === PlayerFramework.VideoMediaPlugin.MediaError.MEDIA_ERR_DECODE))
		{
			this.show(this.options.defaultMessage);
		}
		else if (!this.mediaPlugin())
		{
			this.show(this.options.defaultMessage);
		}
	},

	onNetworkStateChange: function(e)
	{
		///	<summary>
		///		Called when the media element's network state changes.
		///	</summary>

		if (!this.element &&
			this.player.networkState() === PlayerFramework.VideoMediaPlugin.NetworkState.NETWORK_NO_SOURCE)
			this.show(this.options.defaultMessage);
	},

	// Functions
	show: function(text)
	{
		///	<summary>
		///		Creates a message control with the specified text and adds it to the DOM.
		///	</summary>
		///	<param name="text" type="String">
		///		The text to display.
		///	</param>

		window.setTimeout(PlayerFramework.proxy(this, function()
		{
			// Error message control
			this.element = PlayerFramework.createElement(this.player.containerElement,
			[
				"div",
				{
					"class": "pf-error-message-control"
				},
				[
					"div",
					{
						"class": "pf-error-message-container"
					},
					text
				]
			]);
		}), 500);
	}
});
